Errorbar method for mplot3d
---------------------------

The errorbar function `.Axes.errorbar` is ported into the 3D Axes framework in
its entirety, supporting features such as custom styling for error lines and
cap marks, control over erorrbar spacing, upper and lower limit marks.
